#
# spec file for package libelf0
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libelf0
Summary:        An ELF Object File Access Library
License:        LGPL-2.1+
Group:          System/Libraries
BuildRequires:  pkgconfig
Version:        0.8.13
Release:        21.4
Url:            http://www.mr511.de/software/
Source:         http://www.mr511.de/software/libelf-%{version}.tar.gz
Source2:        baselibs.conf
Patch0:         config-guess-sub-update.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bug437293
%ifarch ppc64
Obsoletes:      libelf-64bit
%endif
#
Provides:       libelf = %{version}
Obsoletes:      libelf <= 0.8.10

%description
The libelf package contains a library for accessing ELF object files.
Libelf allows you to access the internals of the ELF object file
format, so you can see the different sections of an ELF file.



Authors:
--------
    Michael Riepe <michael@stud.uni-hannover.de>

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
# bug437293
%ifarch ppc64
Obsoletes:      libelf-devel-64bit
%endif
#
Requires:       %{name} = %{version}
Requires:       glibc-devel
Conflicts:      libelf1-devel

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.



Authors:
--------
    Michael Riepe <michael@stud.uni-hannover.de>

%prep
%setup -q -n libelf-%{version}
%patch0

%build
%configure
make %{?_smp_mflags}

%install
make install instroot=$RPM_BUILD_ROOT
# remove the wrapper includes
rm -f $RPM_BUILD_ROOT%{_includedir}/*.h
# remove unneeded *.la and *.a files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
%find_lang libelf

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f libelf.lang
%defattr(-,root,root)
%{_libdir}/libelf.so.*

%files devel
%defattr(-,root,root)
%doc README ChangeLog COPYING.LIB VERSION
%{_libdir}/libelf.so
%{_libdir}/libelf.a
%{_libdir}/pkgconfig/libelf.pc
%{_includedir}/libelf

%changelog
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Feb  4 2013 schwab@suse.de
- config-guess-sub-update.patch:
  Update config.guess/sub for aarch64
* Wed Feb  1 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Fri Apr 30 2010 meissner@suse.de
- updated to 0.8.13
  - New function elf_getaroff().
  - Build fixes.
* Fri Apr 30 2010 meissner@suse.de
- add buildrequires pkgconfig
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Jul  8 2009 meissner@suse.de
- updated to 0.8.12
  - Due to some unfortunate confusion, the elf_getphnum(),
  elf_getshnum() and elf_getshstrndx() are not compatible
  between libelf implementations. Therefore, the developers
  decided to replace them with new functions: elf_getphdrnum(),
  elf_getshdrnum() and elf_getshdrstrndx(), which will always
  return -1 on failure and 0 on success. Code using the old
  interface should be upgraded to increase portability.
* Tue May 26 2009 meissner@suse.de
- updated to 0.8.11
  - Fixed a bug in elf_rawfile()
  - If you use ELF_F_LAYOUT together with ELF_F_LAYOUT_OVERLAP,
  elf_update() will now tolerate overlapping sections.
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed May  7 2008 coolo@suse.de
- fix package rename
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Mar 15 2008 crrodriguez@suse.de
- fix file-not-in-lang errors
* Fri Oct 12 2007 meissner@suse.de
- upgraded to 0.8.10
  - sanity checking
  - various cleanups and bugfixes
* Mon Jul  2 2007 tiwai@suse.de
- added static lib again (prelink requires it)
* Fri May 18 2007 tiwai@suse.de
- renamed to libelf0 to avoid confliction with elfutils
- split a devel subpackage
- remove static library
* Wed Aug 23 2006 meissner@suse.de
- Upgraded to 0.8.9 with minor bugfixes
* Sat Jul  8 2006 meissner@suse.de
- Upgraded to 0.8.8.
  - added some new helper functions requested
  by GCC (elf_getshstrndx)
  - small bugfixes
* Fri Jul  7 2006 meissner@suse.de
- Upgraded to 0.8.6.
  - lots of bugfixes, some new features
  - pkgconfig file added
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Feb 16 2004 coolo@suse.de
- version update
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Jun  5 2003 coolo@suse.de
- update to 0.8.4
* Wed May 14 2003 coolo@suse.de
- package translation too
* Fri Oct  4 2002 coolo@suse.de
- include two patches by Jakub to make prelinking work
* Wed Jul 10 2002 tcrhak@suse.cz
- update to version 0.8.2
* Fri Mar 15 2002 tcrhak@suse.cz
- added dir /usr/include/libelf to filelist
* Fri Jan 18 2002 tcrhak@suse.cz
- used macros %%{_lib} and %%{_libdir}
- bziped sources
- fixed buildroot, makefile patch
* Tue Oct 16 2001 aj@suse.de
- Fix handling of Elf64_Sxword (upper 32 bits were destroyed).
* Wed Mar 14 2001 fober@suse.de
- added suse_update_config
* Thu Jun  8 2000 cihlar@suse.cz
- added %%clean
* Wed Jan 12 2000 kukuk@suse.de
- Remove ExcludeArch for alpha
* Tue Dec 21 1999 kukuk@suse.de
- Initial version
